%define subver 1.9
%define rubyapi 1.9.1
%define rubyver 1.9.3
%define patchversion p429
%define rel 1

%define libname %mklibname ruby %{subver}

%define ruby_libdir %{_datadir}/%{name}
%define ruby_libarchdir %{_libdir}/%{name}

# This is the local lib/arch and should not be used for packaging.
%define ruby_sitelibdir %{_datadir}/ruby/site_ruby
%define ruby_sitearchdir %{_libdir}/ruby/site_ruby

# This is the general location for libs/archs compatible with all
# or most of the Ruby versions available in the Fedora repositories.
%define ruby_vendorlibdir %{_datadir}/ruby/vendor_ruby
%define ruby_vendorarchdir %{_libdir}/ruby/vendor_ruby

# The RubyGems library has to stay out of Ruby directory three, since the
# RubyGems should be share by all Ruby implementations.
%define rubygems_dir %{_datadir}/ruby/gems
%define rubygems_version 1.8.23

%define bootstrap 0
%define build_gems 0

Summary:	Object Oriented Script Language
Name:		ruby
Version:	%{rubyver}.%{patchversion}
Release: 	%mkrel %rel
License:	Ruby or BSD
Group:		Development/Ruby
BuildRequires:	autoconf
BuildRequires:	byacc
BuildRequires:	doxygen
BuildRequires:	ncurses-devel
BuildRequires:	readline-devel
BuildRequires:	tcl-devel tk-devel
BuildRequires:	db-devel
BuildRequires:  gdbm-devel >= 1.8.3
BuildRequires:  openssl-devel
BuildRequires:	zlib-devel
BuildRequires:	libffi-devel
BuildRequires:	yaml-devel
BuildRequires:	rpm-mageia-setup >= 1.158
Obsoletes:	ruby-rexml
Provides:	ruby-rexml
# explicit file provides (since such requires are automatically added by find-requires)
Provides: /usr/bin/ruby
Provides: ruby(abi) = %rubyapi

Source0:	http://ftp.ruby-lang.org/pub/ruby/%{subver}/ruby-%{rubyver}-%{patchversion}.tar.bz2
Source3:	ruby.macros
URL:		http://www.ruby-lang.org/
%if !%bootstrap
Requires:	rubygems >= %{rubygems_version}
BuildRequires:	ruby
%endif

# == FEDORA PATCHES BEGINS ==
# http://redmine.ruby-lang.org/issues/5231
Patch0: ruby-1.9.3-disable-versioned-paths.patch
# TODO: Should be submitted upstream?
Patch1: ruby-1.9.3-arch-specific-dir.patch
# http://redmine.ruby-lang.org/issues/5281
Patch2: ruby-1.9.3-added-site-and-vendor-arch-flags.patch
# http://redmine.ruby-lang.org/issues/5465
Patch4: ruby-1.9.3-fix-s390x-build.patch
# Fix the uninstaller, so that it doesn't say that gem doesn't exist
# when it exists outside of the GEM_HOME (already fixed in the upstream)
Patch5: ruby-1.9.3-rubygems-1.8.11-uninstaller.patch
# Allows to install RubyGems into custom directory, outside of Ruby's tree.
# http://redmine.ruby-lang.org/issues/5617
Patch8: ruby-1.9.3-custom-rubygems-location.patch
# Add support for installing binary extensions according to FHS.
# https://github.com/rubygems/rubygems/issues/210
Patch9: rubygems-1.8.11-binary-extensions.patch
# == FEDORA PATCHES ENDS ==
# Try to fix parallel build
Patch10: ruby-1.9.3-mkmf-parallel-install.patch

%package	-n %{libname}
Summary:	Libraries necessary to run Ruby
Group:		Development/Ruby

%package	doc
Summary:	Documentation for the powerful language Ruby
Group:		Development/Ruby
BuildArch:	noarch

%package	devel
Summary:	Development file for the powerful language Ruby
Group:		Development/Ruby
Requires:	%{name} = %{version}
Requires:	%{libname} = %{version}

%package	tk
Summary:	Tk extension for the powerful language Ruby
Group:		Development/Ruby
Requires:	%{name} = %{version}

%package	RubyGems
Summary:	The Ruby standard for packaging ruby libraries
Group:		Development/Ruby
Version:	%{rubygems_version}
Requires:	ruby(abi) = %{subver}
Provides:	gem = %{rubygems_version}
Provides:	rubygems = %{rubygems_version}
Provides:	ruby(rubygems) = %{rubygems_version}
Conflicts:	rpm-mageia-setup-build < 1.159
BuildArch:	noarch

%define rake_ver 0.9.2.2
%package	rake
Summary:	Simple ruby build program with capabilities similar to make
Group:		Development/Ruby
Version:	%{rake_ver}
Requires:	ruby(abi) = %{subver}
Provides:	rubygem(rake) = %{rake_ver}
BuildArch:	noarch

%define minitest_ver 2.5.1
%package	minitest
Summary:	Minitest provides a complete suite of testing facilities
Group:		Development/Ruby
Version:	%{minitest_ver}
License:	MIT
Requires:	ruby(abi) = %{subver}
Requires:	ruby(rubygems) >= %{rubygems_version}
Provides:	rubygem(minitest) = %{minitest_ver}
BuildArch:	noarch

%define json_ver 1.5.4
%package	json
Summary:	This is a JSON implementation as a Ruby extension in C
Group:		Development/Ruby
Version:	%{json_ver}
License:	Ruby or GPLv2
Requires:	ruby(abi) = %{subver}
Requires:	ruby(rubygems) >= %{rubygems_version}
Provides:	rubygem(json) = %{json_ver}

%define rdoc_ver 3.9.4
%package	rdoc
Summary:	A tool to generate HTML and command-line documentation for Ruby projects
Group:		Development/Ruby
Version:	%{rdoc_ver}
License:	GPLv2 and Ruby and MIT
Requires:	ruby(abi) = %{subver}
Requires:	ruby(rubygems) >= %{rubygems_version}
Requires:	ruby(irb) = %{version}
Provides:	rdoc = %{rdoc_ver}
Provides:	ri = %{rdoc_ver}
BuildArch:	noarch

%package	irb
Summary:	The Interactive Ruby
Group:		Development/Ruby
Provides:	irb = %{version}-%{release}
Provides:	ruby(irb) = %{version}-%{release}
Conflicts:	ruby < 1.9
BuildArch:	noarch

%package	bigdecimal
Summary:	BigDecimal provides arbitrary-precision floating point decimal arithmetic
Group:		Development/Ruby
Version:	1.1.0
License:	GPL+ or Artistic
Requires:	ruby(abi) = %{subver}
Requires:	ruby(rubygems) >= %{rubygems_version}
Provides:	rubygem(bigdecimal) = 1.1.0

%package	io-console
Summary:	IO/Console is a simple console utilizing library
Group:		Development/Ruby
Version:	0.3
Requires:	ruby(abi) = %{subver}
Requires:	ruby(rubygems) >= %{rubygems_version}
Provides:	rubygem(io-console) = 0.3

%description
Ruby is the interpreted scripting language for quick and
easy object-oriented programming.  It has many features to
process text files and to do system management tasks (as in
Perl).  It is simple, straight-forward, and extensible.

%description	doc
Ruby is the interpreted scripting language for quick and
easy object-oriented programming.  It has many features to
process text files and to do system management tasks (as in
Perl). It is simple, straight-forward, and extensible.

This package contains the Ruby's documentation

%description	-n %{libname}
This package includes the libruby, necessary to run Ruby.

%description	devel
Ruby is the interpreted scripting language for quick and
easy object-oriented programming.  It has many features to
process text files and to do system management tasks (as in
Perl). It is simple, straight-forward, and extensible.

This package contains the Ruby's devel files.

%description	tk
Ruby is the interpreted scripting language for quick and
easy object-oriented programming.  It has many features to
process text files and to do system management tasks (as in
Perl). It is simple, straight-forward, and extensible.

This package contains the Tk extension for Ruby.

%description	RubyGems
RubyGems is the Ruby standard for publishing and managing third party
libraries.

%description	rake
Rake is a Make-like program implemented in Ruby. Tasks and dependencies are
specified in standard Ruby syntax.

%description 	rdoc
RDoc produces HTML and command-line documentation for Ruby projects.  RDoc
includes the 'rdoc' and 'ri' tools for generating and displaying online
documentation.

%description	json
This is a implementation of the JSON specification according to RFC 4627.
You can think of it as a low fat alternative to XML, if you want to store
data to disk or transmit it over a network rather than use a verbose
markup language.

%description	minitest
minitest/unit is a small and incredibly fast unit testing framework.

minitest/spec is a functionally complete spec engine.

minitest/benchmark is an awesome way to assert the performance of your
algorithms in a repeatable manner.

minitest/mock by Steven Baker, is a beautifully tiny mock object
framework.

minitest/pride shows pride in testing and adds coloring to your test
output.

%description	irb
The irb is acronym for Interactive Ruby.  It evaluates ruby expression
from the terminal.

%description	bigdecimal
Ruby provides built-in support for arbitrary precision integer arithmetic.
For example:

42**13 -> 1265437718438866624512

BigDecimal provides similar support for very large or very accurate floating
point numbers. Decimal arithmetic is also useful for general calculation,
because it provides the correct answers people expect–whereas normal binary
floating point arithmetic often introduces subtle errors because of the
conversion between base 10 and base 2.

%description	io-console
IO/Console provides very simple and portable access to console. It doesn't
provide higher layer features, such like curses and readline.

%prep
%setup -q -n ruby-%{rubyver}-%{patchversion}
%apply_patches
# When patching mkmf.rb the mkmf.rb.0010 gets installed
rm lib/mkmf.rb.0*

%build
autoconf
CFLAGS=`echo %optflags | sed 's/-fomit-frame-pointer//'`
%configure2_5x --enable-shared --disable-rpath --enable-pthread --disable-versioned-paths \
	--with-rubylibprefix='%{ruby_libdir}' \
	--with-archdir='%{ruby_libarchdir}' \
	--with-sitedir='%{ruby_sitelibdir}' \
	--with-sitearchdir='%{ruby_sitearchdir}' \
	--with-vendordir='%{ruby_vendorlibdir}' \
	--with-vendorarchdir='%{ruby_vendorarchdir}' \
	--with-rubyhdrdir='%{_includedir}' \
        --with-rubygemsdir='%{rubygems_dir}'
%make

%install
%makeinstall_std install-doc

install -d %buildroot%{_datadir}/emacs/site-lisp
cp -a misc/ruby-mode.el %buildroot%{_datadir}/emacs/site-lisp

install -d %buildroot%{_sysconfdir}/emacs/site-start.d
cat <<EOF >%buildroot%{_sysconfdir}/emacs/site-start.d/%{name}.el
(autoload 'ruby-mode "ruby-mode" "Ruby editing mode." t)
(add-to-list 'auto-mode-alist '("\\\\.rb$" . ruby-mode))
(add-to-list 'interpreter-mode-alist '("ruby" . ruby-mode))
EOF

# Install the rpm macros 
mkdir -p %buildroot%{_sysconfdir}/rpm/macros.d
cp %{SOURCE3} %buildroot%{_sysconfdir}/rpm/macros.d

# drop gems if not wanted, so that we could split them out as seperated source rpm
%if !%build_gems
rm -f %{buildroot}%{_bindir}/{rake,rdoc,ri}
rm -f %{buildroot}%{_mandir}/man1/{rake,ri}.*
rm -fr %{buildroot}%{ruby_libdir}/{minitest,rake,rdoc,json,bigdecimal,io}
rm -fr %{buildroot}%{ruby_libarchdir}/{json,bigdecimal.so,io/console.so}
rm -fr %{buildroot}%{rubygems_dir}/%{rubyapi}
%if !%bootstrap
rm -f %{buildroot}%{_bindir}/gem
rm -fr %{buildroot}%{rubygems_dir}/rbconfig
rm -fr %{buildroot}%{rubygems_dir}/rubygems
rm -f %{buildroot}%{rubygems_dir}/rubygems.rb
rm -f %{buildroot}%{rubygems_dir}/ubygems.rb
%endif
%endif

%check
make test

%files
%{_bindir}/erb
%{_bindir}/ruby
%{_bindir}/testrb
%dir %{ruby_libdir}
%{ruby_libdir}/*.rb
%exclude %{ruby_libdir}/irb.rb
%exclude %{ruby_libdir}/multi-tk.rb
%exclude %{ruby_libdir}/remote-tk.rb
%exclude %{ruby_libdir}/tcltk.rb
%exclude %{ruby_libdir}/tk.rb
%exclude %{ruby_libdir}/tkafter.rb
%exclude %{ruby_libdir}/tkbgerror.rb
%exclude %{ruby_libdir}/tkcanvas.rb
%exclude %{ruby_libdir}/tkclass.rb
%exclude %{ruby_libdir}/tkconsole.rb
%exclude %{ruby_libdir}/tkdialog.rb
%exclude %{ruby_libdir}/tkentry.rb
%exclude %{ruby_libdir}/tkfont.rb
%exclude %{ruby_libdir}/tkmacpkg.rb
%exclude %{ruby_libdir}/tkmenubar.rb
%exclude %{ruby_libdir}/tkmngfocus.rb
%exclude %{ruby_libdir}/tkpalette.rb
%exclude %{ruby_libdir}/tkscrollbox.rb
%exclude %{ruby_libdir}/tktext.rb
%exclude %{ruby_libdir}/tkvirtevent.rb
%exclude %{ruby_libdir}/tkwinpkg.rb
%{ruby_libdir}/cgi
%{ruby_libdir}/date
%{ruby_libdir}/digest
%{ruby_libdir}/dl
%{ruby_libdir}/drb
%{ruby_libdir}/fiddle
%{ruby_libdir}/matrix
%{ruby_libdir}/net
%{ruby_libdir}/openssl
%{ruby_libdir}/optparse
%{ruby_libdir}/psych
%{ruby_libdir}/racc
%{ruby_libdir}/rbconfig
%{ruby_libdir}/rexml
%{ruby_libdir}/rinda
%{ruby_libdir}/ripper
%{ruby_libdir}/rss
%{ruby_libdir}/shell
%{ruby_libdir}/syck
%{ruby_libdir}/test
%{ruby_libdir}/uri
%{ruby_libdir}/webrick
%{ruby_libdir}/xmlrpc
%{ruby_libdir}/yaml
%dir %{ruby_libarchdir}
%{ruby_libarchdir}/continuation.so
%{ruby_libarchdir}/coverage.so
%{ruby_libarchdir}/curses.so
%{ruby_libarchdir}/date_core.so
%{ruby_libarchdir}/dbm.so
%dir %{ruby_libarchdir}/digest
%{ruby_libarchdir}/digest.so
%{ruby_libarchdir}/digest/*.so
%dir %{ruby_libarchdir}/dl
%{ruby_libarchdir}/dl.so
%{ruby_libarchdir}/dl/*.so
%dir %{ruby_libarchdir}/enc
%{ruby_libarchdir}/enc/*.so
%dir %{ruby_libarchdir}/enc/trans
%{ruby_libarchdir}/enc/trans/*.so
%{ruby_libarchdir}/etc.so
%{ruby_libarchdir}/fcntl.so
%{ruby_libarchdir}/fiber.so
%{ruby_libarchdir}/fiddle.so
%{ruby_libarchdir}/gdbm.so
%{ruby_libarchdir}/iconv.so
%dir %{ruby_libarchdir}/io
%{ruby_libarchdir}/io/nonblock.so
%{ruby_libarchdir}/io/wait.so
%dir %{ruby_libarchdir}/mathn
%{ruby_libarchdir}/mathn/*.so
%{ruby_libarchdir}/nkf.so
%{ruby_libarchdir}/objspace.so
%{ruby_libarchdir}/openssl.so
%{ruby_libarchdir}/pathname.so
%{ruby_libarchdir}/psych.so
%{ruby_libarchdir}/pty.so
%dir %{ruby_libarchdir}/racc
%{ruby_libarchdir}/racc/*.so
%{ruby_libarchdir}/rbconfig.rb
%{ruby_libarchdir}/readline.so
%{ruby_libarchdir}/ripper.so
%{ruby_libarchdir}/sdbm.so
%{ruby_libarchdir}/socket.so
%{ruby_libarchdir}/stringio.so
%{ruby_libarchdir}/strscan.so
%{ruby_libarchdir}/syck.so
%{ruby_libarchdir}/syslog.so
%{ruby_libarchdir}/zlib.so
%{_mandir}/man1/erb.1.*
%{_mandir}/man1/ruby.1.*
%{_datadir}/emacs/site-lisp/*
%config(noreplace) %{_sysconfdir}/emacs/site-start.d/*
%{_sysconfdir}/rpm/macros.d/%{name}.macros
%{_datadir}/ruby/site_ruby
%{_libdir}/ruby/site_ruby
%{_datadir}/ruby/vendor_ruby
%{_libdir}/ruby/vendor_ruby
%if %bootstrap
%{_bindir}/gem
%dir %{rubygems_dir}
%{rubygems_dir}/rbconfig
%{rubygems_dir}/rubygems
%{rubygems_dir}/rubygems.rb
%{rubygems_dir}/ubygems.rb
%endif

%files doc
%{_datadir}/ri
%{_datadir}/doc/ruby/html/*

%files -n %{libname}
%{_libdir}/libruby.so.%{subver}
%{_libdir}/libruby.so.%{rubyapi}

%files devel
%{_includedir}/*
%{_libdir}/libruby-static.a
%{_libdir}/libruby.so
%{_libdir}/pkgconfig/*.pc

%files tk
%{ruby_libarchdir}/tcltklib.so
%{ruby_libarchdir}/tkutil.so
%{ruby_libdir}/multi-tk.rb
%{ruby_libdir}/remote-tk.rb
%{ruby_libdir}/tcltk.rb
%{ruby_libdir}/tk.rb
%{ruby_libdir}/tkafter.rb
%{ruby_libdir}/tkbgerror.rb
%{ruby_libdir}/tkcanvas.rb
%{ruby_libdir}/tkclass.rb
%{ruby_libdir}/tkconsole.rb
%{ruby_libdir}/tkdialog.rb
%{ruby_libdir}/tkentry.rb
%{ruby_libdir}/tkfont.rb
%{ruby_libdir}/tkmacpkg.rb
%{ruby_libdir}/tkmenubar.rb
%{ruby_libdir}/tkmngfocus.rb
%{ruby_libdir}/tkpalette.rb
%{ruby_libdir}/tkscrollbox.rb
%{ruby_libdir}/tktext.rb
%{ruby_libdir}/tkvirtevent.rb
%{ruby_libdir}/tkwinpkg.rb
%{ruby_libdir}/tk
%{ruby_libdir}/tkextlib

%files irb
%{_bindir}/irb
%{ruby_libdir}/irb.rb
%{ruby_libdir}/irb
%{_mandir}/man1/irb.1*

%if %build_gems
%files RubyGems
%{_bindir}/gem
%dir %{rubygems_dir}
%{rubygems_dir}/rbconfig
%{rubygems_dir}/rubygems
%{rubygems_dir}/rubygems.rb
%{rubygems_dir}/ubygems.rb

%files minitest
%{ruby_libdir}/minitest
%{rubygems_dir}/%{rubyapi}/specifications/minitest-*.gemspec

%files rake
%{_bindir}/rake
%{_mandir}/man1/rake.1.*
%{ruby_libdir}/rake
%{rubygems_dir}/%{rubyapi}/gems/rake-*
%{rubygems_dir}/%{rubyapi}/specifications/rake-*.gemspec

%files rdoc
%{_bindir}/rdoc
%{_bindir}/ri
%{ruby_libdir}/rdoc
%{rubygems_dir}/%{rubyapi}/gems/rdoc-*
%{rubygems_dir}/%{rubyapi}/specifications/rdoc-*.gemspec
%{_mandir}/man1/ri.1.*

%files json
%dir %{ruby_libarchdir}/json
%dir %{ruby_libarchdir}/json/ext
%{ruby_libarchdir}/json/ext/*.so
%{ruby_libdir}/json
%{rubygems_dir}/%{rubyapi}/specifications/json-*.gemspec

%files bigdecimal
%{ruby_libdir}/bigdecimal
%{ruby_libarchdir}/bigdecimal.so
%{rubygems_dir}/%{rubyapi}/specifications/bigdecimal-*.gemspec

%files io-console
%{ruby_libdir}/io
%{ruby_libarchdir}/io/console.so
%{rubygems_dir}/%{rubyapi}/specifications/io-console-*.gemspec
%endif


%changelog
* Thu May 23 2013 fwang <fwang> 1.9.3.p429-1.mga3
+ Revision: 424700
- new version 1.9.3-p429

* Sun Feb 24 2013 fwang <fwang> 1.9.3.p392-1.mga3
+ Revision: 400216
- new version 1.9.3p392

* Sat Feb 09 2013 kamil <kamil> 1.9.3.p374-5.mga3
+ Revision: 397518
- ruby switched its license alternative from GPLv2 to BSD

* Fri Feb 08 2013 umeabot <umeabot> 1.9.3.p374-4.mga3
+ Revision: 395696
- Rebuild for CVE-2013-0256

* Wed Feb 06 2013 fwang <fwang> 1.9.3.p374-3.mga3
+ Revision: 394856
- fix CVE-2013-0256: XSS exploit of RDoc documentation generated by rdoc

* Tue Jan 22 2013 pterjan <pterjan> 1.9.3.p374-2.mga3
+ Revision: 391153
- Try to fix parallel build

* Fri Jan 18 2013 fwang <fwang> 1.9.3.p374-1.mga3
+ Revision: 389324
- new version 1.9.3-p374

* Mon Jan 14 2013 umeabot <umeabot> 1.9.3.p362-2.mga3
+ Revision: 380587
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Dec 26 2012 fwang <fwang> 1.9.3.p362-1.mga3
+ Revision: 335306
- new version 1.9.3.p362

* Sat Nov 10 2012 fwang <fwang> 1.9.3.p327-1.mga3
+ Revision: 316803
- new version 1.9.3-p327

* Sat Nov 03 2012 fwang <fwang> 1.9.3.p286-6.mga3
+ Revision: 313460
- add conflicts to ease upgrading

* Thu Nov 01 2012 fwang <fwang> 1.9.3.p286-5.mga3
+ Revision: 311925
- drop epoch

* Thu Nov 01 2012 fwang <fwang> 1.9.3.p286-4.mga3
+ Revision: 311924
- update file list
- disable bootstrap build

* Thu Nov 01 2012 fwang <fwang> 1.9.3.p286-3.mga3
+ Revision: 311916
- correctly remove files
- ship gems when building bootstrap
- disable bootstrap build

* Thu Nov 01 2012 fwang <fwang> 1.9.3.p286-2.mga3
+ Revision: 311870
- build bootstrap
- revert rubygems_dir dir
- use fedora dir for rubygems

* Tue Oct 23 2012 fwang <fwang> 1:1.9.3.p286-1.mga3
+ Revision: 309414
- new version 1.9.3p286
- fix provides of ruby-api

* Thu Sep 13 2012 fwang <fwang> 1:1.9.3.p194-9.mga3
+ Revision: 293421
- SIELNT: update file list
- update file list
- when not building gems, delete these files
- br ruby when not doing bootstrap build
- try build without rubygems
- disable rubygems when bootstrap
- update rake ver

* Wed Sep 12 2012 fwang <fwang> 1:1.9.3.p194-8.mga3
+ Revision: 292586
- ensure higher rpm-setup is installed

* Wed Sep 12 2012 fwang <fwang> 1:1.9.3.p194-7.mga3
+ Revision: 292582
- bump req on gem_helper.rb

* Wed Sep 12 2012 fwang <fwang> 1:1.9.3.p194-6.mga3
+ Revision: 292558
- tweak ruby macros so that it is using new config variable
- add requires on rubygems for ruby binary

* Mon Sep 10 2012 shlomif <shlomif> 1:1.9.3.p194-5.mga3
+ Revision: 291767
- Extract some SPEC macros for common version strings

* Mon Sep 10 2012 shlomif <shlomif> 1:1.9.3.p194-4.mga3
+ Revision: 291748
- Add a missing provides for rake

* Mon Sep 10 2012 shlomif <shlomif> 1:1.9.3.p194-3.mga3
+ Revision: 291733
- Make sure summary does not end with dot
- Package missing files
- Add BR on doxygen with its generated and installed files.

  + fwang <fwang>
    - specify correct gem versions
    - split more files
    - specify correct includedir
    - we will provide only one flavour of ruby now, so versioned paths are not needed

* Mon Sep 10 2012 fwang <fwang> 1.9.3.p194-2.mga3
+ Revision: 291553
- update file list
- split out gems and rake

* Sat Sep 08 2012 fwang <fwang> 1.9.3.p194-1.mga3
+ Revision: 290244
- update file list
- fix path patch
- regenerate conf file
- we does not force i386 for now
- sync with fedora patches
- update file list
- add more br
- update file list
- cleanup spec
- new version 1.9.3-p194

* Tue Jul 31 2012 fwang <fwang> 1.8.7.p370-2.mga3
+ Revision: 276350
- rebuild for db-5.3

* Thu Jul 19 2012 fwang <fwang> 1.8.7.p370-1.mga3
+ Revision: 272538
- new version 1.8.7-p370

* Thu Feb 16 2012 fwang <fwang> 1.8.7.p358-1.mga2
+ Revision: 209807
- new version 1.8.7-p358

* Mon Feb 13 2012 pterjan <pterjan> 1.8.7.p357-3.mga2
+ Revision: 208302
- Add patch for CVE-2011-0188

* Sat Jan 28 2012 fwang <fwang> 1.8.7.p357-2.mga2
+ Revision: 202696
- mark doc package as noarch

* Thu Dec 29 2011 fwang <fwang> 1.8.7.p357-1.mga2
+ Revision: 188702
- new version 1.8.7 p367

* Mon Dec 05 2011 fwang <fwang> 1.8.7.p352-2.mga2
+ Revision: 176965
- add fedora wrokround on FTBTS issue
- rebuild for new gdbm

* Sun Jul 03 2011 fwang <fwang> 1.8.7.p352-1.mga2
+ Revision: 117596
- new patch p352

* Sun Feb 20 2011 shikamaru <shikamaru> 1.8.7.p334-1.mga1
+ Revision: 54449
- new patchset 334, fix vulnerability in FileUtils#remove_entry_secure

  + rtp <rtp>
    - Fix directories. Ruby is using different directories between arm & arm eabi

  + pterjan <pterjan>
    - Revert re-import
    - imported package ruby

* Sat Jan 08 2011 blino <blino> 1.8.7.p330-2.mga1
+ Revision: 1166
- remove old mdkversion scriptlets
- imported package ruby

